/*
 * Copyright 2017 Arne Vajhj.
 * 
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License. 
 */

package dk.vajhoej.vms.call;

import dk.vajhoej.record.Alignment;
import dk.vajhoej.record.FieldType;
import dk.vajhoej.record.Struct;
import dk.vajhoej.record.StructField;

/**
 * Class IOSB represents a VMS IOSB structure.
 */
@Struct(alignment=Alignment.PACKED)
public class IOSB {
	@StructField(n=0,type=FieldType.INT2)
	private int status;
	@StructField(n=1,type=FieldType.INT2)
	private int count;
	@StructField(n=2,type=FieldType.INT4)
	private int any;
	/**
	 * Construct new IOSB.
	 */
	public IOSB() {
		this(0, 0, 0);
	}
	/**
	 * Construct new IOSB.
	 * @param status status code
	 * @param count bytes read/write
	 * @param any context specific information
	 */
	public IOSB(int status, int count, int any) {
		this.status = status;
		this.count = count;
		this.any = any;
	}
	/**
	 * Get status.
	 * @return status code
	 */
	public int getStatus() {
		return status;
	}
	/**
	 * Get count.
	 * @return count bytes read/write
	 */
	public int getCount() {
		return count;
	}
	/**
	 * Get context specific information.
	 * @return context specific information
	 */
	public int getAny() {
		return any;
	}
}
