/*
 * Copyright 2017 Arne Vajhj.
 * 
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License. 
 */

package dk.vajhoej.vms.call.test;

import static org.junit.Assert.*;

import static dk.vajhoej.vms.call.lib.VMSCodes.*;

import org.junit.Test;

import dk.vajhoej.vms.call.VMS;
import dk.vajhoej.vms.call.VMSLibrary.Result;
import dk.vajhoej.vms.call.lib.FAB;
import dk.vajhoej.vms.call.lib.RMS.RMS_IO;;

public class TestRMS extends BaseTest {
	@Test
	public void testDISPLAY() {
        try {
        	RMS_IO rms = new RMS_IO();
        	Result<Void> res;
        	res = rms.SYS$OPEN_Read("test.com");
			assertVMSCall("OPEN", res.getStatus());
        	res = rms.SYS$DISPLAY();
			assertVMSCall("DISPLAY", res.getStatus());
			FAB fab = rms.getFAB();
			assertEquals("ORG", FAB$C_SEQ, fab.getOrg());
			assertEquals("RFM", FAB$C_VAR, fab.getRfm());
			assertEquals("RAT", FAB$M_CR, fab.getRat());
        	res = rms.SYS$CLOSE();
			assertVMSCall("CLOSE", res.getStatus());
			
        } catch(Exception ex) {
        	fail("Unexpected exception: " + ex);
        }
	}
	@Test
	public void testGET() {
        try {
        	RMS_IO rms = new RMS_IO();
        	Result<Void> res;
        	res = rms.SYS$OPEN_Read("test.com");
			assertVMSCall("OPEN", res.getStatus());
        	res = rms.SYS$CONNECT();
			assertVMSCall("CONNECT", res.getStatus());
			Result<String> sres;
			int n = 0;
			for(;;) {
				sres = rms.SYS$GET_String();
				if(!VMS.isSuccess(sres.getStatus())) break;
				n++;
				assertVMSCall("GET", sres.getStatus(), sres.getResult());
			}
			assertTrue("GET", n > 0);
        	res = rms.SYS$DISCONNECT();
			assertVMSCall("DISCONNECT", res.getStatus());
			res = rms.SYS$CLOSE();
			assertVMSCall("CLOSE", res.getStatus());
			
        } catch(Exception ex) {
        	fail("Unexpected exception: " + ex);
        }
	}
}
